#!/bin/sh
#### Patch script - GNU Emacs - version 19.33 to 19.34

#### This file contains patches to turn version 19.33 of GNU Emacs into
#### 19.34.  To apply them, cd to the top of the Emacs source tree, and
#### then type 'sh <this file>'.

#### After this script applies the patches, it will attempt to use an
#### existing Emacs to recompile the changed Emacs Lisp files.  (You may
#### use the environment variable $emacs to specify the location of the
#### binary, if it's not in your search path.)  When this is finished,
#### you can build the new Emacs version.

#### We don't include patches for Info files since you can
#### regenerate them from the Texinfo files that we do include.
#### To update the changed info files, do
#### (cd man; make)

if [ "$0" = sh -o ! -f "$0" ]; then
  echo "use \`sh PATCHKIT', not \`sh <PATCHKIT'" >&2
  exit 1
fi
if [ -d lisp ] ; then
  me=$0
elif [ -d emacs-19.33/lisp ] ; then
  cd emacs-19.33
  case $0 in /*) me=$0;; *) me=../$0;; esac
else
  (echo "$0: In order to apply this patch, the current directory"
   echo "must be the top of the Emacs distribution tree.") >&2
  exit 1
fi

### moves and renames
#none

# As noted above, we normally don't bother with info patches -- but since
# `make install' references this new file, it's less confusing if we create
# it if necessary.
if [ ! -f info/message ]; then
  sed -n -e 75,1077p -e 1077q <$me | tr '%&' '\037\177' >info/message
  chmod a+r info/message
fi

tail +1083 $me | patch -p1

cd lisp
for e in $emacs ../src/emacs emacs emacs19 emacs-19 ''; do
  if [ -n "$e" ]; then
    v=`$e --version </dev/null 2>/dev/null | sed -e 's/.* //' -e 's/\.[0-9]*$//'`
    case $v in 19.29*|19.[3-9][0-9]*) break;; esac
  fi
done
if [ -z "$e" ]; then
  (echo "I can't find an Emacs to execute."
   echo "You'll have to byte-compile the lisp directory by hand.") >&2
  exit 0
fi
echo "byte compiling with $e (version $v)..." >&2
loadpath=${TMPDIR-/tmp}/$$.el
trap "rm -f $loadpath; exit 1" 1 2 3 15
echo "(setq load-path (cons \"`pwd`\" load-path))" >$loadpath
# First do the new files, and any older files that might need to be compiled
# in a particular order.  Then do the rest of the directory.
list=

for f in $list; do
  echo Compiling $f...
  $e -batch -l $loadpath -f batch-byte-compile $f
done
$e -batch -l $loadpath -f batch-byte-recompile-directory .
rm $loadpath
exit 0
# The next 1003 lines are an ASCIIfied copy of info/message.
This is Info file ../info/message, produced by Makeinfo-1.63 from the
input file message.texi.

   This file documents Messa, the Emacs message composition mode.

   Copyright (C) 1996 Free Software Foundation, Inc.

   Permission is granted to make and distribute verbatim copies of this
manual provided the copyright notice and this permission notice are
preserved on all copies.

   Permission is granted to copy and distribute modified versions of
this manual under the conditions for verbatim copying, provided also
that the entire resulting derived work is distributed under the terms
of a permission notice identical to this one.

   Permission is granted to copy and distribute translations of this
manual into another language, under the above conditions for modified
versions.

%
File: message,  Node: Top,  Next: Interface,  Up: (dir)

Message
*******

   All message composition (both mail and news) takes place in Message
mode buffers.

* Menu:

* Interface::         Setting up message buffers.
* Commands::          Commands you can execute in message mode buffers.
* Variables::         Customizing the message buffers.
* Index::             Variable, function and concept index.
* Key Index::         List of Message mode keys.

%
File: message,  Node: Interface,  Next: Commands,  Prev: Top,  Up: Top

Interface
*********

   When a program (or a person) wants to respond to a message - reply,
follow up, forward, cancel - the program (or person) should just put
point in the buffer where the message is and call the required command.
`Message' will then pop up a new `message' mode buffer with appropriate
headers filled out, and the user can edit the message before sending it.

* Menu:

* New Mail Message::     Editing a brand new mail message.
* New News Message::     Editing a brand new news message.
* Reply::                Replying via mail.
* Wide Reply::           Responding to all people via mail.
* Followup::             Following up via news.
* Canceling News::       Canceling a news article.
* Superseding::          Superseding a message.
* Forwarding::           Forwarding a message via news or mail.
* Resending::            Resending a mail message.
* Bouncing::             Bouncing a mail message.

%
File: message,  Node: New Mail Message,  Next: New News Message,  Up: Interface

New Mail Message
================

   The `message-mail' command pops up a new message buffer.

   Two optional parameters are accepted: The first will be used as the
`To' header and the second as the `Subject' header.  If these aren't
present, those two headers will be empty.

%
File: message,  Node: New News Message,  Next: Reply,  Prev: New Mail Message,  Up: Interface

New News Message
================

   The `message-news' command pops up a new message buffer.

   This function accepts two optional parameters.  The first will be
used as the `Newsgroups' header and the second as the `Subject' header.
If these aren't present, those two headers will be empty.

%
File: message,  Node: Reply,  Next: Wide Reply,  Prev: New News Message,  Up: Interface

Reply
=====

   The `message-reply' function pops up a message buffer that's a reply
to the message in the current buffer.

   Message uses the normal methods to determine where replies are to go,
but you can change the behavior to suit your needs by fiddling with the
`message-reply-to-function' variable.

   If you want the replies to go to the `Sender' instead of the `From',
you could do something like this:

     (setq message-reply-to-function
           (lambda ()
            (cond ((equal (mail-fetch-field "from") "somebody")
                    (mail-fetch-field "sender"))
                  (t
                   nil))))

   This function will be called narrowed to the head of the article
that is being replied to.

   As you can see, this function should return a string if it has an
opinion as to what the To header should be.  If it does not, it should
just return `nil', and the normal methods for determining the To header
will be used.

   This function can also return a list.  In that case, each list
element should be a cons, where the car should be the name of an header
(eg. `Cc') and the cdr should be the header value (eg.
`larsi@ifi.uio.no').  All these headers will be inserted into the head
of the outgoing mail.

%
File: message,  Node: Wide Reply,  Next: Followup,  Prev: Reply,  Up: Interface

Wide Reply
==========

   The `message-wide-reply' pops up a message buffer that's a wide
reply to the message in the current buffer.

   Message uses the normal methods to determine where wide replies are
to go, but you can change the behavior to suit your needs by fiddling
with the `message-wide-reply-to-function'.  It is used in the same way
as `message-reply-to-function' (*note Reply::.).

   Addresses that matches the `rmail-dont-reply-to-names' regular
expression will be removed from the `Cc' header.

%
File: message,  Node: Followup,  Next: Canceling News,  Prev: Wide Reply,  Up: Interface

Followup
========

   The `message-followup' command pops up a message buffer that's a
followup to the message in the current buffer.

   Message uses the normal methods to determine where followups are to
go, but you can change the behavior to suit your needs by fiddling with
the `message-followup-to-function'.  It is used in the same way as
`message-reply-to-function' (*note Reply::.).

   The `message-use-followup-to' variable says what to do about
`Followup-To' headers.  If it is `use', always use the value.  If it is
`ask' (which is the default), ask whether to use the value.  If it is
`t', use the value unless it is `poster'.  If it is `nil', don't use
the value.

%
File: message,  Node: Canceling News,  Next: Superseding,  Prev: Followup,  Up: Interface

Canceling News
==============

   The `message-cancel-news' command cancels the article in the current
buffer.

%
File: message,  Node: Superseding,  Next: Forwarding,  Prev: Canceling News,  Up: Interface

Superseding
===========

   The `message-supersede' command pops up a message buffer that will
supersede the message in the current buffer.

   Headers matching the `message-ignored-supersedes-headers' are
removed before popping up the new message buffer.  The default is
`^Path:\\|^Date\\|^NNTP-Posting-Host:\\|^Xref:\\|^Lines:\\|^Received:\\|^X-From-Line:\\|Return-Path:'.

%
File: message,  Node: Forwarding,  Next: Resending,  Prev: Superseding,  Up: Interface

Forwarding
==========

   The `message-forward' command pops up a message buffer to forward
the message in the current buffer.  If given a prefix, forward using
news.

`message-forward-start-separator'
     Delimiter inserted before forwarded messages.  The default is
     `------- Start of forwarded message -------\n'.

`message-forward-end-separator'
     Delimiter inserted after forwarded messages.  The default is
     `------- End of forwarded message -------\n'.

`message-signature-before-forwarded-message'
     If this variable is `t', which it is by default, your personal
     signature will be inserted before the forwarded message.  If not,
     the forwarded message will be inserted first in the new mail.

`message-included-forward-headers'
     Regexp matching header lines to be included in forwarded messages.

%
File: message,  Node: Resending,  Next: Bouncing,  Prev: Forwarding,  Up: Interface

Resending
=========

   The `message-resend' command will prompt the user for an address and
resend the message in the current buffer to that address.

   Headers the match the `message-ignored-resent-headers' regexp will
be removed before sending the message.  The default is
`^Return-receipt'.

%
File: message,  Node: Bouncing,  Prev: Resending,  Up: Interface

Bouncing
========

   The `message-bounce' command will, if the current buffer contains a
bounced mail message, pop up a message buffer stripped of the bounce
information.

   Headers that match the `message-ignored-bounced-headers' regexp will
be removed before popping up the buffer.  The default is `^Received:'.

%
File: message,  Node: Commands,  Next: Variables,  Prev: Interface,  Up: Top

Commands
********

* Menu:

* Header Commands::     Commands for moving to headers.
* Movement::            Moving around in message buffers.
* Insertion::           Inserting things into message buffers.
* Various Commands::    Various things.
* Sending::             Actually sending the message.

%
File: message,  Node: Header Commands,  Next: Movement,  Up: Commands

Header Commands
===============

   All these commands move to the header in question.  If it doesn't
exist, it will be inserted.

`C-c ?'
     Describe the message mode.

`C-c C-f C-t'
     Go to the `To' header (`message-goto-to').

`C-c C-f C-b'
     Go to the `Bcc' header (`message-goto-bcc').

`C-c C-f C-f'
     Go to the `Fcc' header (`message-goto-fcc').

`C-c C-f C-c'
     Go to the `Cc' header (`message-goto-cc').

`C-c C-f C-s'
     Go to the `Subject' header (`message-goto-subject').

`C-c C-f C-r'
     Go to the `Reply-To' header (`message-goto-reply-to').

`C-c C-f C-n'
     Go to the `Newsgroups' header (`message-goto-newsgroups').

`C-c C-f C-d'
     Go to the `Distribution' header (`message-goto-distribution').

`C-c C-f C-o'
     Go to the `Followup-To' header (`message-goto-followup-to').

`C-c C-f C-k'
     Go to the `Keywords' header (`message-goto-keywords').

`C-c C-f C-u'
     Go to the `Summary' header (`message-goto-summary').

%
File: message,  Node: Movement,  Next: Insertion,  Prev: Header Commands,  Up: Commands

Movement
========

`C-c C-b'
     Move to the beginning of the body of the message
     (`message-goto-body').

`C-c C-i'
     Move to the signature of the message (`message-goto-signature').

%
File: message,  Node: Insertion,  Next: Various Commands,  Prev: Movement,  Up: Commands

Insertion
=========

`C-c C-y'
     Yank the message that's being replied to into the message buffer
     (`message-yank-original').

`C-c C-q'
     Fill the yanked message (`message-fill-yanked-message').

`C-c C-w'
     Insert a signature at the end of the buffer
     (`message-insert-signature').

`message-ignored-cited-headers'
     All headers that match this regexp will be removed from yanked
     messages.  The default is `.', which means that all headers will be
     removed.

`message-citation-line-function'
     Function called to insert the citation line.  The default is
     `message-insert-citation-line'.

`message-yank-prefix'
     When you are replying to or following up an article, you normally
     want to quote the person you are answering.  Inserting quoted text
     is done by "yanking", and each quoted line you yank will have
     `message-yank-prefix' prepended to it.  The default is `> '.  If
     it is `nil', just indent the message.

`message-indentation-spaces'
     Number of spaces to indent yanked messages.

`message-cite-function'
     Function for citing an original message.  The default is
     `message-cite-original'.  You can also set it to
     `sc-cite-original' to use Supercite.

`message-indent-citation-function'
     Function for modifying a citation just inserted in the mail buffer.
     This can also be a list of functions.  Each function can find the
     citation between `(point)' and `(mark t)'.  And each function
     should leave point and mark around the citation text as modified.

`message-signature'
     String to be inserted at the end of the message buffer.  If `t'
     (which is the default), the `message-signature-file' file will be
     inserted instead.  If a function, the result from the function
     will be used instead.  If a form, the result from the form will be
     used instead.  If this variable is `nil', no signature will be
     inserted at all.

`message-signature-file'
     File containing the signature to be inserted at the end of the
     buffer.  The default is `~/.signature'.

   Note that RFC1036 says that a signature should be preceded by the
three characters `-- ' on a line by themselves.  This is to make it
easier for the recipient to automatically recognize and process the
signature.  So don't remove those characters, even though you might feel
that they ruin you beautiful design, like, totally.

   Also note that no signature should be more than four lines long.
Including ASCII graphics is an efficient way to get everybody to believe
that you are silly and have nothing important to say.

%
File: message,  Node: Various Commands,  Next: Sending,  Prev: Insertion,  Up: Commands

Various Commands
================

`C-c C-r'
     Caesar rotate (aka. rot13) the current message
     (`message-caesar-buffer-body').  If narrowing is in effect, just
     rotate the visible portion of the buffer.  A numerical prefix says
     how many places to rotate the text.  The default is 13.

`C-c C-t'
     Insert a `To' header that contains the `Reply-To' or `From' header
     of the message you're following up (`message-insert-to').

`C-c C-n'
     Insert a `Newsgroups' header that reflects the `Followup-To' or
     `Newsgroups' header of the article you're replying to
     (`message-insert-newsgroups').

`C-c M-r'
     Rename the buffer (`message-rename-buffer').  If given a prefix,
     prompt for a new buffer name.

%
File: message,  Node: Sending,  Prev: Various Commands,  Up: Commands

Sending
=======

`C-c C-c'
     Send the message and bury the current buffer
     (`message-send-and-exit').

`C-c C-s'
     Send the message (`message-send').

`C-c C-d'
     Bury the message buffer and exit (`message-dont-send').

`C-c C-k'
     Kill the message buffer and exit (`message-kill-buffer').

%
File: message,  Node: Variables,  Next: Index,  Prev: Commands,  Up: Top

Variables
*********

* Menu:

* Message Headers::             General message header stuff.
* Mail Headers::                Customizing mail headers.
* Mail Variables::              Other mail variables.
* News Headers::                Customizing news headers.
* News Variables::              Other news variables.
* Various Message Variables::   Other message variables.
* Sending Variables::           Variables for sending.
* Message Buffers::             How Message names its buffers.
* Message Actions::             Actions to be performed when exiting.

%
File: message,  Node: Message Headers,  Next: Mail Headers,  Up: Variables

Message Headers
===============

   Message is quite aggressive on the message generation front.  It has
to be - it's a combined news and mail agent.  To be able to send
combined messages, it has to generate all headers itself to ensure that
mail and news copies of messages look sufficiently similar.

`message-generate-headers-first'
     If non-`nil', generate all headers before starting to compose the
     message.

`message-from-style'
     Specifies how `From' headers should look.  There are four legal
     values:

    `nil'
          Just the address - `king@grassland.com'.

    `parens'
          `king@grassland.com (Elvis Parsley)'.

    `angles'
          `Elvis Parsley <king@grassland.com>'.

    `default'
          Look like `angles' if that doesn't require quoting, and
          `parens' if it does.  If even `parens' requires quoting, use
          `angles' anyway.

`message-deletable-headers'
     Headers in this list that were previously generated by Message
     will be deleted before posting.  Let's say you post an article.
     Then you decide to post it again to some other group, you naughty
     boy, so you jump back to the `*post-buf*' buffer, edit the
     `Newsgroups' line, and ship it off again.  By default, this
     variable makes sure that the old generated `Message-ID' is
     deleted, and a new one generated.  If this isn't done, the entire
     empire would probably crumble, anarchy would prevail, and cats
     would start walking on two legs and rule the world.  Allegedly.

`message-default-headers'
     This string is inserted at the end of the headers in all message
     buffers.

%
File: message,  Node: Mail Headers,  Next: Mail Variables,  Prev: Message Headers,  Up: Variables

Mail Headers
============

`message-required-mail-headers'
     See *note News Headers::. for the syntax of this variable.  It is
     `(From Date Subject (optional . In-Reply-To) Message-ID Lines
     (optional . X-Mailer))' by default.

`message-ignored-mail-headers'
     Regexp of headers to be removed before mailing.  The default is
     `^Gcc:\\|^Fcc:'.

`message-default-mail-headers'
     This string is inserted at the end of the headers in all message
     buffers that are initialized as mail.

%
File: message,  Node: Mail Variables,  Next: News Headers,  Prev: Mail Headers,  Up: Variables

Mail Variables
==============

`message-send-mail-function'
     Function used to send the current buffer as mail.  The default is
     `message-send-mail-with-sendmail'.   If you prefer using MH
     instead, set this variable to `message-send-mail-with-mh'.

%
File: message,  Node: News Headers,  Next: News Variables,  Prev: Mail Variables,  Up: Variables

News Headers
============

   `message-required-news-headers' a list of header symbols.  These
headers will either be automatically generated, or, if that's
impossible, they will be prompted for.  The following symbols are legal:

`From'
     This required header will be filled out with the result of the
     `message-make-from' function, which depends on the
     `message-from-style', `user-full-name', `user-mail-address'
     variables.

`Subject'
     This required header will be prompted for if not present already.

`Newsgroups'
     This required header says which newsgroups the article is to be
     posted to.  If it isn't present already, it will be prompted for.

`Organization'
     This optional header will be filled out depending on the
     `message-user-organization' variable.
     `message-user-organization-file' will be used if that variable is
     `t'.

`Lines'
     This optional header will be computed by Message.

`Message-ID'
     This required header will be generated by Message.  A unique ID
     will be created based on date, time, user name and system name.
     Message will use `mail-host-address' as the fully qualified domain
     name (FQDN) of the machine if that variable is define.  If not, it
     will use `system-name', which doesn't report a FQDN on some
     machines - notably Suns.

`X-Newsreader'
     This optional header will be filled out according to the
     `message-newsreader' local variable.

`X-Mailer'
     This optional header will be filled out according to the
     `message-mailer' local variable, unless there already is an
     `X-Newsreader' header present.

`In-Reply-To'
     This optional header is filled out using the `Date' and `From'
     header of the article being replied.

`Expires'
     This extremely optional header will be inserted according to the
     `message-expires' variable.  It is highly deprecated and shouldn't
     be used unless you know what you're doing.

`Distribution'
     This optional header is filled out according to the
     `message-distribution-function' variable.  It is a deprecated and
     much misunderstood header.

`Path'
     This extremely optional header should probably not ever be used.
     However, some *very* old servers require that this header is
     present.  `message-user-path' further controls how this `Path'
     header is to look.  If is is `nil', the the server name as the
     leaf node.  If is is a string, use the string.  If it is neither a
     string nor `nil', use the user name only.  However, it is highly
     unlikely that you should need to fiddle with this variable at all.

   In addition, you can enter conses into this list.  The car of this
cons should be a symbol.  This symbol's name is the name of the header,
and the cdr can either be a string to be entered verbatim as the value
of this header, or it can be a function to be called.  This function
should return a string to be inserted.  For instance, if you want to
insert `Mime-Version: 1.0', you should enter `(Mime-Version . "1.0")'
into the list.  If you want to insert a funny quote, you could enter
something like `(X-Yow . yow)' into the list.  The function `yow' will
then be called without any arguments.

   If the list contains a cons where the car of the cons is `optional',
the cdr of this cons will only be inserted if it is non-`nil'.

   Other variables for customizing outgoing news articles:

`message-syntax-checks'
     If non-`nil', message will attempt to check the legality of the
     headers, as well as some other stuff, before posting.  You can
     control the granularity of the check by adding or removing
     elements from this list.  Legal elements are:

    `subject-cmsg'
          Check the subject for commands.

    `sender'
          Insert a new `Sender' header if the `From' header looks odd.

    `multiple-headers'
          Check for the existence of multiple equal headers.

    `sendsys'
          Check for the existence of version and sendsys commands.

    `message-id'
          Check whether the `Message-ID' looks ok.

    `from'
          Check whether the `From' header seems nice.

    `long-lines'
          Check for too long lines.

    `control-chars'
          Check for illegal characters.

    `size'
          Check for excessive size.

    `new-text'
          Check whether there is any new text in the messages.

    `signature'
          Check the length of the signature.

    `approved'
          Check whether the article has an `Approved' header, which is
          something only moderators should include.

    `empty'
          Check whether the article is empty.

    `empty-headers'
          Check whether any of the headers are empty.

    `existing-newsgroups'
          Check whether the newsgroups mentioned in the Newsgroups and
          Followup-To headers exist.

    `valid-newsgroups'
          Check whether the `Newsgroups' and `Followup-To' headers are
          valid syntactially.

     All these conditions are checked by default.

`message-ignored-news-headers'
     Regexp of headers to be removed before posting.  The default is
     `^NNTP-Posting-Host:\\|^Xref:\\|^Bcc:\\|^Gcc:\\|^Fcc:'.

`message-default-news-headers'
     This string is inserted at the end of the headers in all message
     buffers that are initialized as news.

%
File: message,  Node: News Variables,  Next: Various Message Variables,  Prev: News Headers,  Up: Variables

News Variables
==============

`message-send-news-function'
     Function used to send the current buffer as news.  The default is
     `message-send-news'.

`message-post-method'
     Method used for posting a prepared news message.

%
File: message,  Node: Various Message Variables,  Next: Sending Variables,  Prev: News Variables,  Up: Variables

Various Message Variables
=========================

`message-signature-separator'
     Regexp matching the signature separator.  It is `^-- *$' by
     default.

`mail-header-separator'
     String used to separate the headers from the body.  It is `--text
     follows this line--' by default.

`message-directory'
     Directory used by many mailey things.  The default is `~/Mail/'.

`message-autosave-directory'
     Directory where message buffers will be autosaved to.

`message-signature-setup-hook'
     Hook run when initializing the message buffer.  It is run after the
     headers have been inserted but before the signature has been
     inserted.

`message-setup-hook'
     Hook run as the last thing when the message buffer has been
     initialized.

`message-header-setup-hook'
     Hook called narrowed to the headers after initializing the headers.

`message-send-hook'
     Hook run before sending messages.

`message-sent-hook'
     Hook run after sending messages.

`message-mode-syntax-table'
     Syntax table used in message mode buffers.

%
File: message,  Node: Sending Variables,  Next: Message Buffers,  Prev: Various Message Variables,  Up: Variables

Sending Variables
=================

`message-fcc-handler-function'
     A function called to save outgoing articles.  This function will be
     called with the name of the file to store the article in. The
     default function is `rmail-output' which saves in Unix mailbox
     format.

`message-courtesy-message'
     When sending combined messages, this string is inserted at the
     start of the mailed copy.  If this variable is `nil', no such
     courtesy message will be added.

%
File: message,  Node: Message Buffers,  Next: Message Actions,  Prev: Sending Variables,  Up: Variables

Message Buffers
===============

   Message will generate new buffers with unique buffer names when you
request a message buffer.  When you send the message, the buffer isn't
normally killed off.  It's name is changed and a certain number of old
message buffers are kept alive.

`message-generate-new-buffers'
     If non-`nil', generate new buffers.  The default is `t'.  If this
     is a function, call that function with three parameters: The type,
     the to address and the group name.  (Any of these may be `nil'.)
     The function should return the new buffer name.

`message-max-buffers'
     This variable says how many old message buffers to keep.  If there
     are more message buffers than this, the oldest buffer will be
     killed.  The default is 10.  If this variable is `nil', no old
     message buffers will ever be killed.

`message-send-rename-function'
     After sending a message, the buffer is renamed from, for instance,
     `*reply to Lars*' to `*sent reply to Lars*'.  If you don't like
     this, set this variable to a function that renames the buffer in a
     manner you like.  If you don't want to rename the buffer at all,
     you can say:

          (setq message-send-rename-function 'ignore)

`message-kill-buffer-on-exit'
     If non-`nil', kill the buffer immediately on exit.

%
File: message,  Node: Message Actions,  Prev: Message Buffers,  Up: Variables

Message Actions
===============

   When Message is being used from a news/mail reader, the reader is
likely to want to perform some task after the message has been sent.
Perhaps return to the previous window configuration or mark an article
as replied.

   The user may exit from the message buffer in various ways.  The most
common is `C-c C-c', which sends the message and exits.  Other
possibilities are `C-c C-s' which just sends the message, `C-c C-d'
which postpones the message editing and buries the message buffer, and
`C-c C-k' which kills the message buffer.  Each of these actions have
lists associated with them that contains actions to be executed:
`message-send-actions', `message-exit-actions',
`message-postpone-actions', and `message-kill-actions'.

   Message provides a function to interface with these lists:
`message-add-action'.  The first parameter is the action to be added,
and the rest of the arguments are which lists to add this action to.
Here's an example from Gnus:

       (message-add-action
        `(set-window-configuration ,(current-window-configuration))
        'exit 'postpone 'kill)

   This restores the Gnus window configuration when the message buffer
is killed, postponed or exited.

   An "action" can be either a normal function; or a list where the
`car' is a function and the `cdr' is the list of arguments; or a form
to be `eval'ed.

%
File: message,  Node: Index,  Next: Key Index,  Prev: Variables,  Up: Top

Index
*****

* Menu:

* approved:                             News Headers.
* Distribution:                         News Headers.
* Expires:                              News Headers.
* From:                                 News Headers.
* Lines:                                News Headers.
* long lines:                           News Headers.
* mail-header-separator:                Various Message Variables.
* mail-host-address:                    News Headers.
* message-autosave-directory:           Various Message Variables.
* message-bounce:                       Bouncing.
* message-caesar-buffer-body:           Various Commands.
* message-cancel-news:                  Canceling News.
* message-citation-line-function:       Insertion.
* message-cite-function:                Insertion.
* message-cite-original:                Insertion.
* message-courtesy-message:             Sending Variables.
* message-default-headers:              Message Headers.
* message-default-mail-headers:         Mail Headers.
* message-default-news-headers:         News Headers.
* message-deletable-headers:            Message Headers.
* message-directory:                    Various Message Variables.
* message-dont-send:                    Sending.
* message-exit-actions:                 Message Actions.
* message-fcc-handler-function:         Sending Variables.
* message-fill-yanked-message:          Insertion.
* message-followup:                     Followup.
* message-followup-to-function:         Followup.
* message-forward:                      Forwarding.
* message-forward-end-separator:        Forwarding.
* message-forward-start-separator:      Forwarding.
* message-from-style:                   Message Headers.
* message-generate-headers-first:       Message Headers.
* message-generate-new-buffers:         Message Buffers.
* message-goto-bcc:                     Header Commands.
* message-goto-body:                    Movement.
* message-goto-cc:                      Header Commands.
* message-goto-distribution:            Header Commands.
* message-goto-fcc:                     Header Commands.
* message-goto-followup-to:             Header Commands.
* message-goto-keywords:                Header Commands.
* message-goto-newsgroups:              Header Commands.
* message-goto-reply-to:                Header Commands.
* message-goto-signature:               Movement.
* message-goto-subject:                 Header Commands.
* message-goto-summary:                 Header Commands.
* message-goto-to:                      Header Commands.
* message-header-setup-hook:            Various Message Variables.
* Message-ID:                           News Headers.
* message-ignored-bounced-headers:      Bouncing.
* message-ignored-cited-headers:        Insertion.
* message-ignored-mail-headers:         Mail Headers.
* message-ignored-news-headers:         News Headers.
* message-ignored-resent-headers:       Resending.
* message-ignored-supersedes-headers:   Superseding.
* message-included-forward-headers:     Forwarding.
* message-indent-citation-function:     Insertion.
* message-indentation-spaces:           Insertion.
* message-insert-newsgroups:            Various Commands.
* message-insert-signature:             Insertion.
* message-insert-to:                    Various Commands.
* message-kill-actions:                 Message Actions.
* message-kill-buffer:                  Sending.
* message-kill-buffer-on-exit:          Message Buffers.
* message-mail:                         New Mail Message.
* message-max-buffers:                  Message Buffers.
* message-mode-syntax-table:            Various Message Variables.
* message-news:                         New News Message.
* message-post-method:                  News Variables.
* message-postpone-actions:             Message Actions.
* message-rename-buffer:                Various Commands.
* message-reply:                        Reply.
* message-reply-to-function:            Reply.
* message-required-mail-headers:        Mail Headers.
* message-required-news-headers:        News Headers.
* message-resend:                       Resending.
* message-send:                         Sending.
* message-send-actions:                 Message Actions.
* message-send-and-exit:                Sending.
* message-send-hook:                    Various Message Variables.
* message-send-mail-function:           Mail Variables.
* message-send-news-function:           News Variables.
* message-send-rename-function:         Message Buffers.
* message-sent-hook:                    Various Message Variables.
* message-setup-hook:                   Various Message Variables.
* message-signature:                    Insertion.
* message-signature-before-forwarded-message: Forwarding.
* message-signature-file:               Insertion.
* message-signature-separator:          Various Message Variables.
* message-signature-setup-hook:         Various Message Variables.
* message-supersede:                    Superseding.
* message-syntax-checks:                News Headers.
* message-use-followup-to:              Followup.
* message-wide-reply:                   Wide Reply.
* message-wide-reply-to-function:       Wide Reply.
* message-yank-original:                Insertion.
* message-yank-prefix:                  Insertion.
* Mime-Version:                         News Headers.
* Newsgroups:                           News Headers.
* organization:                         News Headers.
* path:                                 News Headers.
* quoting:                              Insertion.
* rmail-dont-reply-to-names:            Wide Reply.
* sc-cite-original:                     Insertion.
* Sender:                               News Headers.
* sendsys:                              News Headers.
* Subject:                              News Headers.
* Sun:                                  News Headers.
* Supercite:                            Insertion.
* system-name:                          News Headers.
* user-full-name:                       News Headers.
* user-mail-address:                    News Headers.
* X-Newsreader:                         News Headers.
* yanking:                              Insertion.
* yow:                                  News Headers.

%
File: message,  Node: Key Index,  Prev: Index,  Up: Top

Key Index
*********

* Menu:

* C-c ?:                                Header Commands.
* C-c C-b:                              Movement.
* C-c C-c:                              Sending.
* C-c C-d:                              Sending.
* C-c C-f C-b:                          Header Commands.
* C-c C-f C-c:                          Header Commands.
* C-c C-f C-d:                          Header Commands.
* C-c C-f C-f:                          Header Commands.
* C-c C-f C-k:                          Header Commands.
* C-c C-f C-n:                          Header Commands.
* C-c C-f C-o:                          Header Commands.
* C-c C-f C-r:                          Header Commands.
* C-c C-f C-s:                          Header Commands.
* C-c C-f C-t:                          Header Commands.
* C-c C-f C-u:                          Header Commands.
* C-c C-i:                              Movement.
* C-c C-k:                              Sending.
* C-c C-n:                              Various Commands.
* C-c C-q:                              Insertion.
* C-c C-r:                              Various Commands.
* C-c C-s:                              Sending.
* C-c C-t:                              Various Commands.
* C-c C-w:                              Insertion.
* C-c C-y:                              Insertion.
* C-c M-r:                              Various Commands.


%
Tag Table:
Node: Top&788
Node: Interface&1246
Node: New Mail Message&2243
Node: New News Message&2605
Node: Reply&2998
Node: Wide Reply&4334
Node: Followup&4930
Node: Canceling News&5701
Node: Superseding&5906
Node: Forwarding&6377
Node: Resending&7300
Node: Bouncing&7684
Node: Commands&8069
Node: Header Commands&8449
Node: Movement&9489
Node: Insertion&9773
Node: Various Commands&12475
Node: Sending&13304
Node: Variables&13684
Node: Message Headers&14322
Node: Mail Headers&16040
Node: Mail Variables&16648
Node: News Headers&17007
Node: News Variables&22452
Node: Various Message Variables&22798
Node: Sending Variables&23980
Node: Message Buffers&24587
Node: Message Actions&26018
Node: Index&27485
Node: Key Index&33854
%
End Tag Table
# end of ASCIIfied info/message
#
# The rest of this file is the patch kit.  It's not enclosed in a
# here-document because some shells can't deal with that if it gets
# too large.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/ChangeLog emacs-19.34/ChangeLog
*** emacs-19.33/ChangeLog	Sun Aug 11 03:38:23 1996
--- emacs-19.34/ChangeLog	Wed Aug 21 16:30:00 1996
***************
*** 1,2 ****
--- 1,16 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
+ Sun Aug 18 16:29:40 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* configure.in (NON_GCC_LINK_TEST_OPTIONS, GCC_LINK_TEST_OPTIONS):
+ 	New variables that affect linking only.
+ 	(alpha-dec-osf*): Use those instead of previous change.
+ 
+ Thu Aug 15 14:47:29 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Makefile.in (install-arch-indep): Install info/messages.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/Makefile.in emacs-19.34/Makefile.in
*** emacs-19.33/Makefile.in	Mon Jun  3 16:05:39 1996
--- emacs-19.34/Makefile.in	Tue Aug 20 00:12:19 1996
*************** install-arch-indep: mkdir
*** 376,380 ****
  	   (cd $${thisdir}; ${INSTALL_DATA} ${srcdir}/info/dir ${infodir}/dir); \
  	   (cd $${thisdir}; chmod a+r ${infodir}/dir); \
! 	   for f in ccmode* cl* dired-x* ediff* emacs* forms* gnus* info* mh-e* sc* vip*; do \
  	     (cd $${thisdir}; \
  	      ${INSTALL_DATA} ${srcdir}/info/$$f ${infodir}/$$f; \
--- 376,380 ----
  	   (cd $${thisdir}; ${INSTALL_DATA} ${srcdir}/info/dir ${infodir}/dir); \
  	   (cd $${thisdir}; chmod a+r ${infodir}/dir); \
! 	   for f in ccmode* cl* dired-x* ediff* emacs* forms* gnus* info* message* mh-e* sc* vip*; do \
  	     (cd $${thisdir}; \
  	      ${INSTALL_DATA} ${srcdir}/info/$$f ${infodir}/$$f; \
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/PROBLEMS emacs-19.34/PROBLEMS
*** emacs-19.33/PROBLEMS	Fri Aug  9 06:48:06 1996
--- emacs-19.34/PROBLEMS	Wed Aug 21 03:51:31 1996
*************** This file describes various problems tha
*** 2,5 ****
--- 2,12 ----
  in compiling, installing and running GNU Emacs.
  
+ * Emacs crashes in x-popup-dialog.
+ 
+ This can happen if the dialog widget cannot find the font it wants to
+ use.  You can work around the problem by specifying another font with
+ an X resource--for example, `Emacs.dialog*.font: 9x15' (or any font that
+ happens to exist on your X server).
+ 
  * Emacs crashes when you use Bibtex mode.
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/README emacs-19.34/README
*** emacs-19.33/README	Mon Aug 12 21:10:26 1996
--- emacs-19.34/README	Thu Aug 22 00:43:52 1996
***************
*** 1,3 ****
! This directory tree holds version 19.33 of GNU Emacs, the extensible,
  customizable, self-documenting real-time display editor.
  
--- 1,3 ----
! This directory tree holds version 19.34 of GNU Emacs, the extensible,
  customizable, self-documenting real-time display editor.
  
*************** There are several subdirectories:
*** 74,78 ****
  
  `msdos' holds configuration files for compiling Emacs under MSDOG.
-     See the file etc/MSDOS for more information.
  `cpp' holds a C preprocessor for use instead of the installed one when
      the installed one fails to distinguish more than 8 characters in a
--- 74,77 ----
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/configure emacs-19.34/configure
*** emacs-19.33/configure	Sun Aug 11 03:36:36 1996
--- emacs-19.34/configure	Tue Aug 20 00:11:26 1996
*************** case "${canonical}" in
*** 749,754 ****
      machine=alpha opsys=osf1
      # This is needed to find X11R6.1 libraries for certain tests.
!     NON_GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
!     GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
    ;;
  
--- 749,754 ----
      machine=alpha opsys=osf1
      # This is needed to find X11R6.1 libraries for certain tests.
!     NON_GCC_LINK_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
!     GCC_LINK_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
    ;;
  
*************** if test x$GCC = x && test "x$NON_GCC_TES
*** 1653,1656 ****
--- 1653,1666 ----
  then
    CC="$CC $NON_GCC_TEST_OPTIONS"
+ fi
+ 
+ if test x$GCC = xyes && test "x$GCC_LINK_TEST_OPTIONS" != x
+ then
+   ac_link="$ac_link $GCC_LINK_TEST_OPTIONS"
+ fi
+ 
+ if test x$GCC = x && test "x$NON_GCC_LINK_TEST_OPTIONS" != x
+ then
+   ac_link="$ac_link $NON_GCC_LINK_TEST_OPTIONS"
  fi
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/configure.in emacs-19.34/configure.in
*** emacs-19.33/configure.in	Sat Aug 10 14:51:08 1996
--- emacs-19.34/configure.in	Tue Aug 20 00:11:11 1996
*************** case "${canonical}" in
*** 191,196 ****
      machine=alpha opsys=osf1
      # This is needed to find X11R6.1 libraries for certain tests.
!     NON_GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
!     GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
    ;;
  
--- 191,196 ----
      machine=alpha opsys=osf1
      # This is needed to find X11R6.1 libraries for certain tests.
!     NON_GCC_LINK_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
!     GCC_LINK_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
    ;;
  
*************** if test x$GCC = x && test "x$NON_GCC_TES
*** 974,977 ****
--- 974,987 ----
  then
    CC="$CC $NON_GCC_TEST_OPTIONS"
+ fi
+ 
+ if test x$GCC = xyes && test "x$GCC_LINK_TEST_OPTIONS" != x
+ then
+   ac_link="$ac_link $GCC_LINK_TEST_OPTIONS"
+ fi
+ 
+ if test x$GCC = x && test "x$NON_GCC_LINK_TEST_OPTIONS" != x
+ then
+   ac_link="$ac_link $NON_GCC_LINK_TEST_OPTIONS"
  fi
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/etc/ChangeLog emacs-19.34/etc/ChangeLog
*** emacs-19.33/etc/ChangeLog	Sun Aug 11 03:40:09 1996
--- emacs-19.34/etc/ChangeLog	Wed Aug 21 03:53:13 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/etc/NEWS emacs-19.34/etc/NEWS
*** emacs-19.33/etc/NEWS	Wed Aug  7 15:50:15 1996
--- emacs-19.34/etc/NEWS	Wed Aug 21 12:18:03 1996
***************
*** 1,3 ****
! GNU Emacs NEWS -- history of user-visible changes.  1 Aug 1996
  Copyright (C) 1993, 1994, 1995, 1996 Free Software Foundation, Inc.
  See the end for copying conditions.
--- 1,3 ----
! GNU Emacs NEWS -- history of user-visible changes.  19 Aug 1996
  Copyright (C) 1993, 1994, 1995, 1996 Free Software Foundation, Inc.
  See the end for copying conditions.
*************** Please send Emacs bug reports to bug-gnu
*** 6,9 ****
--- 6,11 ----
  For older news, see the file ONEWS.
  
+ * Emacs 19.34 has no user-visible changes, just bug fixes.
+ 
  * Changes in Emacs 19.33.
  
*************** mode should do that--it is the user's ch
*** 12,16 ****
  
  ** The variable normal-auto-fill-function specifies the function to
! use for auto-fill-functyion, if and when Auto Fill is turned on.
  Major modes can set this locally to alter how Auto Fill works.
  
--- 14,18 ----
  
  ** The variable normal-auto-fill-function specifies the function to
! use for auto-fill-function, if and when Auto Fill is turned on.
  Major modes can set this locally to alter how Auto Fill works.
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/etc/TODO emacs-19.34/etc/TODO
*** emacs-19.33/etc/TODO	Fri Aug  9 07:01:33 1996
--- emacs-19.34/etc/TODO	Tue Aug 20 00:51:19 1996
***************
*** 3,14 ****
    and then parse the output to find out about each file.
  
- * Change bibtex.el not to use very complicated regexps
-   which do lots of backtracking.  Currently bibtex.el
-   makes Emacs crash on some systems due to stack overflow.
-   Making Emacs prevent the stack overflow (by detecting an error
-   itself before the stack can overflow) would just make bibtex,el
-   fail on ALL systems.  The only way out is to rewrite bibtex.el
-   so it does not need too much stack.
- 
  * Change the Windows NT menu code
    so that it handles the deep_p argument and avoids
--- 3,6 ----
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/lib-src/ChangeLog emacs-19.34/lib-src/ChangeLog
*** emacs-19.33/lib-src/ChangeLog	Sun Aug 11 03:39:28 1996
--- emacs-19.34/lib-src/ChangeLog	Wed Aug 21 03:53:22 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/lisp/ChangeLog emacs-19.34/lisp/ChangeLog
*** emacs-19.33/lisp/ChangeLog	Sun Aug 11 17:02:20 1996
--- emacs-19.34/lisp/ChangeLog	Wed Aug 21 03:52:22 1996
***************
*** 1,2 ****
--- 1,11 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
+ Thu Aug 15 02:54:13 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* mouse.el (mouse-drag-region): Don't call mouse-set-region-1
+ 	if mark is gone or no longer active or if we changed buffers.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/lisp/mouse.el emacs-19.34/lisp/mouse.el
*** emacs-19.33/lisp/mouse.el	Fri Jul 12 20:54:21 1996
--- emacs-19.34/lisp/mouse.el	Tue Aug 20 00:07:34 1996
*************** remains active.  Otherwise, it remains u
*** 595,600 ****
  		    (goto-char region-termination)
  		    (copy-region-as-kill (point) (mark t))
! 		    (mouse-show-mark)
! 		    (mouse-set-region-1))
  		(goto-char (overlay-end mouse-drag-overlay))
  		(setq this-command 'mouse-set-point)
--- 595,607 ----
  		    (goto-char region-termination)
  		    (copy-region-as-kill (point) (mark t))
! 		    (let ((buffer (current-buffer)))
! 		      (mouse-show-mark)
! 		      ;; mouse-show-mark can call read-event,
! 		      ;; and that means the Emacs server could switch buffers
! 		      ;; under us.  If that happened, 
! 		      ;; avoid trying to use the region.
! 		      (and (mark t) mark-active
! 			   (eq buffer (current-buffer))
! 			   (mouse-set-region-1))))
  		(goto-char (overlay-end mouse-drag-overlay))
  		(setq this-command 'mouse-set-point)
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/lisp/version.el emacs-19.34/lisp/version.el
*** emacs-19.33/lisp/version.el	Sun Aug 11 03:36:56 1996
--- emacs-19.34/lisp/version.el	Tue Aug 20 00:07:16 1996
***************
*** 25,29 ****
  ;;; Code:
  
! (defconst emacs-version "19.33" "\
  Version numbers of this version of Emacs.")
  
--- 25,29 ----
  ;;; Code:
  
! (defconst emacs-version "19.34" "\
  Version numbers of this version of Emacs.")
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/lwlib/ChangeLog emacs-19.34/lwlib/ChangeLog
*** emacs-19.33/lwlib/ChangeLog	Sun Aug 11 16:52:17 1996
--- emacs-19.34/lwlib/ChangeLog	Wed Aug 21 03:52:52 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/man/ChangeLog emacs-19.34/man/ChangeLog
*** emacs-19.33/man/ChangeLog	Sun Aug 11 03:39:17 1996
--- emacs-19.34/man/ChangeLog	Wed Aug 21 03:53:07 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/man/anti.texi emacs-19.34/man/anti.texi
*** emacs-19.33/man/anti.texi	Tue Aug  6 18:13:49 1996
--- emacs-19.34/man/anti.texi	Wed Aug 21 12:04:12 1996
***************
*** 8,12 ****
    For those users who live backwards in time, here is information about
  downgrading to Emacs version 19.28 or 19.29.  We hope you will enjoy the
! greater simplicity that results from the absence of certain Emacs 19.33
  features.
  
--- 8,12 ----
    For those users who live backwards in time, here is information about
  downgrading to Emacs version 19.28 or 19.29.  We hope you will enjoy the
! greater simplicity that results from the absence of certain Emacs 19.34
  features.
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/man/emacs.texi emacs-19.34/man/emacs.texi
*** emacs-19.33/man/emacs.texi	Tue Aug  6 18:15:44 1996
--- emacs-19.34/man/emacs.texi	Tue Aug 20 00:15:12 1996
***************
*** 4,8 ****
  @c The edition number appears in several places in this file
  This corresponds to the twelfth edition of the @cite{GNU Emacs Manual},
! for Emacs version 19.33.
  @c Please REMEMBER to update edition number in *three* places in this file.
  
--- 4,8 ----
  @c The edition number appears in several places in this file
  This corresponds to the twelfth edition of the @cite{GNU Emacs Manual},
! for Emacs version 19.34.
  @c Please REMEMBER to update edition number in *three* places in this file.
  
*************** original English.
*** 64,68 ****
  @center @titlefont{GNU Emacs Manual}
  @sp 4
! @center Twelfth Edition, Updated for Emacs Version 19.33
  @sp 5
  @center Richard Stallman
--- 64,68 ----
  @center @titlefont{GNU Emacs Manual}
  @sp 4
! @center Twelfth Edition, Updated for Emacs Version 19.34
  @sp 5
  @center Richard Stallman
*************** Copyright @copyright{} 1985, 1986, 1987,
*** 72,76 ****
  @sp 2
  Twelfth Edition @*
! Updated for Emacs Version 19.33, @*
  August 1996
  
--- 72,76 ----
  @sp 2
  Twelfth Edition @*
! Updated for Emacs Version 19.34, @*
  August 1996
  
*************** Emacs is the extensible, customizable, s
*** 111,115 ****
  display editor.  This Info file describes how to edit with Emacs
  and some of how to customize it, but not how to extend it.  It
! corresponds to GNU Emacs version 19.33.
  
  @end ifinfo
--- 111,115 ----
  display editor.  This Info file describes how to edit with Emacs
  and some of how to customize it, but not how to extend it.  It
! corresponds to GNU Emacs version 19.34.
  
  @end ifinfo
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/msdos/ChangeLog emacs-19.34/msdos/ChangeLog
*** emacs-19.33/msdos/ChangeLog	Sun Aug 11 03:39:37 1996
--- emacs-19.34/msdos/ChangeLog	Wed Aug 21 03:52:33 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/nt/ChangeLog emacs-19.34/nt/ChangeLog
*** emacs-19.33/nt/ChangeLog	Sun Aug 11 03:40:00 1996
--- emacs-19.34/nt/ChangeLog	Wed Aug 21 03:52:39 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/oldXMenu/ChangeLog emacs-19.34/oldXMenu/ChangeLog
*** emacs-19.33/oldXMenu/ChangeLog	Sun Aug 11 03:39:06 1996
--- emacs-19.34/oldXMenu/ChangeLog	Wed Aug 21 03:53:00 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/src/ChangeLog emacs-19.34/src/ChangeLog
*** emacs-19.33/src/ChangeLog	Sun Aug 11 03:38:11 1996
--- emacs-19.34/src/ChangeLog	Wed Aug 21 16:30:17 1996
***************
*** 1,2 ****
--- 1,30 ----
+ Wed Aug 21 03:51:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.34 released.
+ 
+ 	* unexalpha.c: Conditionalize previous changes on not __linux__.
+ 
+ Tue Aug 20 16:54:55 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* unexalpha.c: Include reloc.h and elf_abi.h.
+ 	(rel_dyn_section, dynstr_section, dynsym_section): New variables.
+ 	(old_data_scnhdr): New variable.
+ 	(CHECK_SCNHDR): Compare just 8 chars of section name.
+ 	(unexec): Check for rel_dyn_section, dynsym_section, dynstr_section.
+ 	Do call update_dynamic_symbols.
+ 	(update_dynamic_symbols): Finish it up and take away #if 0.
+ 
+ Mon Aug 19 12:53:25 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* unexalpha.c (unexec): Copy the .got section.
+ 
+ Fri Aug 16 15:07:33 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* bytecode.c (Fbyte_code): For relative gotos, force signed arithmetic.
+ 
+ Wed Aug 14 16:58:33 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* xfns.c (Fx_open_connection): Don't set Vx_resource_name.
+ 
  Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/src/bytecode.c emacs-19.34/src/bytecode.c
*** emacs-19.33/src/bytecode.c	Tue Apr  9 18:12:31 1996
--- emacs-19.34/src/bytecode.c	Tue Aug 20 00:05:47 1996
*************** If the third argument is incorrect, Emac
*** 476,480 ****
  	case BRgoto:
  	  QUIT;
! 	  pc += *pc - 127;
  	  break;
  
--- 476,480 ----
  	case BRgoto:
  	  QUIT;
! 	  pc += (int) *pc - 127;
  	  break;
  
*************** If the third argument is incorrect, Emac
*** 483,487 ****
  	    {
  	      QUIT;
! 	      pc += *pc - 128;
  	    }
  	  pc++;
--- 483,487 ----
  	    {
  	      QUIT;
! 	      pc += (int) *pc - 128;
  	    }
  	  pc++;
*************** If the third argument is incorrect, Emac
*** 492,496 ****
  	    {
  	      QUIT;
! 	      pc += *pc - 128;
  	    }
  	  pc++;
--- 492,496 ----
  	    {
  	      QUIT;
! 	      pc += (int) *pc - 128;
  	    }
  	  pc++;
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/src/unexalpha.c emacs-19.34/src/unexalpha.c
*** emacs-19.33/src/unexalpha.c	Mon Jan 15 04:06:29 1996
--- emacs-19.34/src/unexalpha.c	Wed Aug 21 16:29:00 1996
*************** Boston, MA 02111-1307, USA.  */
*** 32,35 ****
--- 32,39 ----
  #include <scnhdr.h>
  #include <syms.h>
+ #ifndef __linux__
+ # include <reloc.h>
+ # include <elf_abi.h>
+ #endif
  
  static void fatal_unexec ();
*************** extern int errno;
*** 53,61 ****
  extern char *strerror ();
  
! void *sbrk();
  
  #define EEOF -1
  
  static struct scnhdr *text_section;
  static struct scnhdr *init_section;
  static struct scnhdr *finit_section;
--- 57,68 ----
  extern char *strerror ();
  
! void *sbrk ();
  
  #define EEOF -1
  
  static struct scnhdr *text_section;
+ static struct scnhdr *rel_dyn_section;
+ static struct scnhdr *dynstr_section;
+ static struct scnhdr *dynsym_section;
  static struct scnhdr *init_section;
  static struct scnhdr *finit_section;
*************** static struct scnhdr *sbss_section;
*** 72,75 ****
--- 79,84 ----
  static struct scnhdr *bss_section;
  
+ static struct scnhdr old_data_scnhdr;
+ 
  static unsigned long Brk;
  
*************** unexec (new_name, a_name, data_start, bs
*** 158,162 ****
    ptr = NULL;								\
    for (i = 0; i < nhdr.fhdr.f_nscns && !ptr; i++)			\
!     if (strcmp (nhdr.section[i].s_name, name) == 0)			\
        {									\
  	if (nhdr.section[i].s_flags != flags)				\
--- 167,171 ----
    ptr = NULL;								\
    for (i = 0; i < nhdr.fhdr.f_nscns && !ptr; i++)			\
!     if (strncmp (nhdr.section[i].s_name, name, 8) == 0)			\
        {									\
  	if (nhdr.section[i].s_flags != flags)				\
*************** unexec (new_name, a_name, data_start, bs
*** 168,171 ****
--- 177,189 ----
    CHECK_SCNHDR (text_section,  _TEXT,  STYP_TEXT);
    CHECK_SCNHDR (init_section,  _INIT,  STYP_INIT);
+ #ifdef _REL_DYN
+   CHECK_SCNHDR (rel_dyn_section, _REL_DYN,  STYP_REL_DYN);
+ #endif /* _REL_DYN */
+ #ifdef _DYNSYM
+   CHECK_SCNHDR (dynsym_section, _DYNSYM,  STYP_DYNSYM);
+ #endif /* _REL_DYN */
+ #ifdef _DYNSTR
+   CHECK_SCNHDR (dynstr_section, _DYNSTR,  STYP_DYNSTR);
+ #endif /* _REL_DYN */
  #ifdef _FINI
    CHECK_SCNHDR (finit_section, _FINI,  STYP_FINI);
*************** unexec (new_name, a_name, data_start, bs
*** 201,204 ****
--- 219,224 ----
    Brk = brk;
  
+   bcopy (data_section, &old_data_scnhdr, sizeof (old_data_scnhdr));
+ 
    nhdr.aout.dsize = brk - DATA_START;
    nhdr.aout.bsize = 0;
*************** unexec (new_name, a_name, data_start, bs
*** 267,270 ****
--- 287,292 ----
    if (got_section != NULL)
      {
+       bcopy (got_section, buffer, sizeof (struct scnhdr));
+ 
        got_section->s_vaddr = vaddr;
        got_section->s_paddr = vaddr;
*************** unexec (new_name, a_name, data_start, bs
*** 293,296 ****
--- 315,333 ----
  	 "writing data section to %s", new_name);
  
+ #ifdef _GOT
+ #define old_got_section ((struct scnhdr *)buffer)
+ 
+   if (got_section != NULL)
+     {
+       SEEK (new, old_got_section->s_scnptr,
+ 	    "seeking to start of got_section in %s", new_name);
+       WRITE (new, oldptr + old_got_section->s_scnptr, old_got_section->s_size,
+ 	     "writing new got_section of %s", new_name);
+       SEEK (new, nhdr.aout.tsize + nhdr.aout.dsize,
+ 	    "seeking to end of data section of %s", new_name);
+     }
+ 
+ #undef old_got_section
+ #endif
  
    /*
*************** unexec (new_name, a_name, data_start, bs
*** 325,337 ****
  	 "writing symbol table of %s", new_name);
  
! #if 0
! 
! /* Not needed for now */
! 
!   update_dynamic_symbols (oldptr, new_name, new, newsyms,
! 			  ((pHDRR) (oldptr + ohdr.fhdr.f_symptr))->issExtMax,
!                           ((pHDRR) (oldptr + ohdr.fhdr.f_symptr))->cbExtOffset,
!                           ((pHDRR) (oldptr + ohdr.fhdr.f_symptr))->cbSsExtOffset);
! 
  #endif
  
--- 362,367 ----
  	 "writing symbol table of %s", new_name);
  
! #ifndef __linux__
!   update_dynamic_symbols (oldptr, new_name, new, nhdr.aout);
  #endif
  
*************** unexec (new_name, a_name, data_start, bs
*** 348,414 ****
  
  
- #if 0
- 
- /* Not needed for now */
- 
- /* The following function updates the values of some symbols
-    that are used by the dynamic loader:
  
-    _edata
-    _end
  
! */
  
! 
! update_dynamic_symbols (old, new_name, new, newsyms, nsyms, symoff, stroff)
       char *old;			/* Pointer to old executable */
       char *new_name;            /* Name of new executable */
       int new;			/* File descriptor for new executable */
!      long newsyms;		/* Offset of Symbol table in new executable */
!      int nsyms;			/* Number of symbol table entries */
!      long symoff;		/* Offset of External Symbols in old file */
!      long stroff;		/* Offset of string table in old file */
  {
!   long i;
!   int found = 0;
!   EXTR n_end, n_edata;
! 
!   /* We go through the symbol table entries until we have found the two
!      symbols. */
! 
!   /* cbEXTR is the size of an external symbol table entry */
! 
!   for (i = 0; i < nsyms && found < 2; i += cbEXTR)
!     {
!       register pEXTR x = (pEXTR) (old + symoff + i);
!       char *s;
!   
!       s = old + stroff + x->asym.iss; /* name of the symbol */
! 
!       if (!strcmp(s,"_edata"))
! 	{
! 	  found++;
!           bcopy (x, &n_edata, cbEXTR);
! 	  n_edata.asym.value = Brk;
! 	  SEEK (new, newsyms + cbHDRR + i,
! 		"seeking to symbol _edata in %s", new_name);
! 	  WRITE (new, &n_edata, cbEXTR,
! 		 "writing symbol table entry for _edata into %s", new_name);
! 	}
!       else if (!strcmp(s,"_end"))
! 	{
! 	  found++;
!           bcopy (x, &n_end, cbEXTR);
! 	  n_end.asym.value = Brk;
! 	  SEEK (new, newsyms + cbHDRR + i,
! 		"seeking to symbol _end in %s", new_name);
! 	  WRITE (new, &n_end, cbEXTR,
! 		 "writing symbol table entry for _end into %s", new_name);
! 	}
      }
  
  }
  
! #endif
  
  
--- 378,462 ----
  
  
  
  
! #ifndef __linux__
  
! update_dynamic_symbols (old, new_name, new, aout)
       char *old;			/* Pointer to old executable */
       char *new_name;            /* Name of new executable */
       int new;			/* File descriptor for new executable */
!      struct aouthdr aout;	/* a.out info from the file header */
  {
!   typedef struct dynrel_info {
!     char * addr;
!     unsigned type:8;
!     unsigned index:24;
!     unsigned info:8;
!     unsigned pad:8;
!   } dr_info;
! 
!   int nsyms = rel_dyn_section->s_size / sizeof (struct dynrel_info);
!   int i;
!   dr_info * rd_base = (dr_info *) (old + rel_dyn_section->s_scnptr);
!   Elf32_Sym * ds_base = (Elf32_Sym *) (old + dynsym_section->s_scnptr);
! 
!   for (i = 0; i < nsyms; i++) {
!     register Elf32_Sym x;
! 
!     if (rd_base[i].index == 0)
!       continue;
! 
!     x = ds_base[rd_base[i].index];
! 
! #if 0
!       fprintf (stderr, "Object inspected: %s, addr = %lx, shndx = %x",
! 	       old + dynstr_section->s_scnptr + x.st_name, rd_base[i].addr, x.st_shndx);
! #endif
! 
! 
!     if ((ELF32_ST_BIND (x.st_info) == STB_GLOBAL)
! 	&& (x.st_shndx == 0)
! 	/* && (x.st_value == NULL) */
! 	) {
!       /* OK, this is probably a reference to an object in a shared
! 	 library, so copy the old value. This is done in several steps:
! 	 1. reladdr is the address of the location in question relative to
!             the start of the data section,
!          2. oldref is the addr is the mapped in temacs executable,
!          3. newref is the address of the location in question in the
!             undumped executable,
!          4. len is the size of the object reference in bytes --
!             currently only 4 (long) and 8 (quad) are supported.
! 	    */
!       register unsigned long reladdr = rd_base[i].addr - old_data_scnhdr.s_vaddr;
!       char * oldref = old + old_data_scnhdr.s_scnptr + reladdr;
!       unsigned long newref = aout.tsize + reladdr;
!       int len;
! 
! #if 0
!       fprintf (stderr, "...relocated\n");
! #endif
! 
!       if (rd_base[i].type == R_REFLONG) 
! 	len = 4;
!       else if (rd_base[i].type == R_REFQUAD) 
! 	len = 8;
!       else
! 	fatal_unexec ("unrecognized relocation type in .dyn.rel section (symbol #%d)", i);
! 
!       SEEK (new, newref, "seeking to dynamic symbol in %s", new_name);
!       WRITE (new, oldref, len, "writing old dynrel info in %s", new_name);
      }
  
+ #if 0
+     else
+       fprintf (stderr, "...not relocated\n");
+ #endif
+ 
+   }
+ 
  }
  
! #endif /* !__linux__ */
  
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.33/src/xfns.c emacs-19.34/src/xfns.c
*** emacs-19.33/src/xfns.c	Tue Jul 16 19:11:37 1996
--- emacs-19.34/src/xfns.c	Tue Aug 20 00:06:18 1996
*************** terminate Emacs if we can't open the con
*** 4902,4908 ****
      xrm_option = (unsigned char *) 0;
  
-   /* Use this general default value to start with.  */
-   Vx_resource_name = Vinvocation_name;
- 
    validate_x_resource_name ();
  
--- 4902,4905 ----
